pitchtools.get_named_pitch_from_pitch_carrier
=============================================

.. autofunction:: abjad.tools.pitchtools.get_named_pitch_from_pitch_carrier.get_named_pitch_from_pitch_carrier
